@@ -5,26 +5,48 @@ from octue.utils.encoders import OctueJSONEncoder
 
 
 class Serialisable:
-    """Mixin class to make resources serialisable to JSON.
+    """A mixin class to make instances serialisable as JSON.
+
+    When calling ``Serialisable.serialise``, by default, only public attributes are included. If the class variable
+    ``_SERIALISE_FIELDS`` is specified, then only these exact attributes are included (these can include non-public
+    attributes); conversely, if ``_EXCLUDE_SERIALISE_FIELDS`` is specified and ``_SERIALISE_FIELDS`` is not, then all
+    public attributes are included apart from the excluded ones.
+
+    By default, JSON conversion is carried out using the ``OctueJSONEncoder``, which will sort keys as well as format
+    and indent automatically. Additional keyword arguments will be passed to ``json.dumps`` to allow other formatting
+    options.
+
+    For example:
+
+    .. code-block:: python
+
+        class MyThing(Serialisable):
+
+            _SERIALISE_FIELDS = ("a",)
+
+            def __init__(self):
+                self.a = 1
+                self.b = 2
+                self._private = 3
+                self.__protected = 4
+
+        MyThing().to_primitive()
+        >>> {"a": 1}
 
-    The `logger` field is always excluded from serialisation if it is present.
     """
 
     _SERIALISE_FIELDS = None
-    _EXCLUDE_SERIALISE_FIELDS = ("logger",)
+    _EXCLUDE_SERIALISE_FIELDS = tuple()
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        if "logger" not in self._EXCLUDE_SERIALISE_FIELDS:
-            self._EXCLUDE_SERIALISE_FIELDS = (*self._EXCLUDE_SERIALISE_FIELDS, "logger")
-
     @classmethod
     def deserialise(cls, serialised_object, from_string=False):
-        """Deserialise the given JSON-serialised object.
+        """Deserialise the given JSON-serialised object into an instance of the class.
 
-        :param str|dict serialised_object:
-        :param bool from_string:
+        :param str|dict serialised_object: the string or dictionary of python primitives to deserialise into an instance
+        :param bool from_string: if ``True``, deserialise from a JSON string; otherwise, deserialise from a dictionary
         :return any:
         """
         if from_string:
@@ -33,34 +55,16 @@ class Serialisable:
         return cls(**serialised_object)
 
     def serialise(self, **kwargs):
-        """Serialise to a JSON string of primitives. By default, only public attributes are included. If the class
-        variable `_SERIALISE_FIELDS` is specified, then only these exact attributes are included (these can include
-        non-public attributes); conversely, if `_EXCLUDE_SERIALISE_FIELDS` is specified and `_SERIALISE_FIELDS` is not,
-        then all public attributes are included apart from the excluded ones. By default, the conversion is carried out
-        using the `OctueJSONEncoder`, which will sort keys as well as format and indent automatically. Additional
-        keyword arguments will be passed to ``json.dumps()`` to enable full override of formatting options.
+        """Serialise the instance to a JSON string of primitives. See the ``Serialisable`` constructor for more
+        information.
 
-        For example:
-        ```
-        class MyThing(Serialisable):
-            _SERIALISE_FIELDS = ("a",)
-            def __init__(self):
-                self.a = 1
-                self.b = 2
-                self._private = 3
-                self.__protected = 4
-
-        MyThing().to_primitive()
-        {"a": 1}
-        ```
-
-        :return str: JSON string containing a serialised primitive version of the resource
+        :return str: a JSON string containing the instance as a serialised python primitive
         """
         return json.dumps(self.to_primitive(), cls=OctueJSONEncoder, sort_keys=True, indent=4, **kwargs)
 
     def to_primitive(self):
-        """Convert the instance into a JSON-compatible python dictionary of its attributes as primitives. The same rules
-        as described in `serialise` apply.
+        """Convert the instance into a JSON-compatible python dictionary of its attributes as primitives. See the
+        ``Serialisable`` constructor for more information.
 
         :return dict:
         """
@@ -88,7 +92,7 @@ class Serialisable:
         return self_as_primitive
 
     def to_file(self, filename, **kwargs):
-        """Write the object to a JSON file.
+        """Write the instance to a JSON file.
 
         :param str filename: path of file to write to, including relative or absolute path and .json extension
         :return None:
