@@ -85,8 +85,18 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
         self.output_location = kwargs.pop("output_location", None)
 
         self._calculate_strand_hashes(strands=strand_kwargs)
+        self._finalised = False
         super().__init__(**kwargs)
 
+    @property
+    def finalised(self):
+        """Check whether the analysis has been finalised (i.e. whether its outputs have been validated and, if an output
+        manifest is produced, its datasets uploaded).
+
+        :return bool:
+        """
+        return self._finalised
+
     def send_monitor_message(self, data):
         """Send a monitor message to the parent that requested the analysis.
 
@@ -120,6 +130,7 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
             serialised_strands["output_manifest"] = self.output_manifest.to_primitive()
 
         self.twine.validate(**serialised_strands)
+        self._finalised = True
         logger.info("Validated output values and output manifest against the twine.")
 
         if not (upload_output_datasets_to and hasattr(self, "output_manifest")):
@@ -127,7 +138,8 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
 
         for name, dataset in self.output_manifest.datasets.items():
             dataset.upload(cloud_path=storage.path.join(upload_output_datasets_to, name))
-            self.output_manifest.datasets[name].path = dataset.generate_signed_url()
+
+        self.output_manifest.use_signed_urls_for_datasets()
 
         logger.info("Uploaded output datasets to %r.", upload_output_datasets_to)
 
